core.match_filter.template
---------------------------

.. currentmodule:: eqcorrscan.core.match_filter.template
.. automodule:: eqcorrscan.core.match_filter.template

----

.. comment to end block

.. autoclass:: Template

   .. rubric:: Methods

   .. autosummary::

      construct
      copy
      detect
      read
      same_processing
      write

   .. automethod:: __init__
   .. automethod:: construct
   .. automethod:: copy
   .. automethod:: detect
   .. automethod:: read
   .. automethod:: same_processing
   .. automethod:: write

Functions
----

.. autofunction:: read_template

.. comment to end block